@@ -1,9 +1,9 @@
 Facter.add(:macaddress) do
-    confine :operatingsystem => %w{Solaris Linux Fedora RedHat CentOS SuSE SLES Debian Gentoo Ubuntu}
+    confine :operatingsystem => %w{Solaris Linux Fedora RedHat CentOS SuSE SLES Debian Gentoo Ubuntu OEL OVS}
     setcode do
         ether = []
         output = %x{/sbin/ifconfig -a}
-        output.each do |s|
+        output.each_line do |s|
             ether.push($1) if s =~ /(?:ether|HWaddr) (\w{1,2}:\w{1,2}:\w{1,2}:\w{1,2}:\w{1,2}:\w{1,2})/
         end
         ether[0]
@@ -15,7 +15,7 @@ Facter.add(:macaddress) do
     setcode do
     ether = []
         output = %x{/sbin/ifconfig}
-        output.each do |s|
+        output.each_line do |s|
             if s =~ /(?:ether|lladdr)\s+(\w\w:\w\w:\w\w:\w\w:\w\w:\w\w)/
                 ether.push($1)
             end
@@ -47,12 +47,12 @@ Facter.add(:macaddress) do
         ether = []
         ip = nil
         output = %x{/usr/sbin/ifconfig -a}
-        output.each do |str|
+        output.each_line do |str|
             if str =~ /([a-z]+\d+): flags=/
                 devname = $1
                 unless devname =~ /lo0/
                     output2 = %x{/usr/bin/entstat #{devname}}
-                    output2.each do |str2|
+                    output2.each_line do |str2|
                         if str2 =~ /^Hardware Address: (\w{1,2}:\w{1,2}:\w{1,2}:\w{1,2}:\w{1,2}:\w{1,2})/
                             ether.push($1)
                         end
@@ -69,7 +69,7 @@ Facter.add(:macaddress) do
     setcode do
         ether = []
         output = %x{ipconfig /all}
-        output.split(/\r\n/).each  do |str|
+        output.split(/\r\n/).each do |str|
             if str =~  /.*Physical Address.*: (\w{1,2}-\w{1,2}-\w{1,2}-\w{1,2}-\w{1,2}-\w{1,2})/
                 ether.push($1.gsub(/-/, ":"))
             end
