@@ -1,52 +1,39 @@
+require 'facter/util/virtual'
+
 Facter.add("virtual") do
     confine :kernel => %w{Linux FreeBSD OpenBSD SunOS}
 
     result = "physical"
 
     setcode do
-    require 'thread'
 
-        if FileTest.exists?("/sbin/zonename")
-            z = %x{"/sbin/zonename"}.chomp
-            if z != 'global'
-                result = 'zone' 
+        result = "zone" if Facter::Util::Virtual.zone?
+
+        if Facter::Util::Virtual.openvz?
+            result = Facter::Util::Virtual.openvz_type()
+        end
+
+        if Facter::Util::Virtual.vserver?
+            result = Facter::Util::Virtual.vserver_type()
+        end
+
+        if Facter::Util::Virtual.xen?
+            # new Xen domains have this in dom0 not domu :(
+            if FileTest.exists?("/proc/sys/xen/independent_wallclock")
+                result = "xenu"
             end
-        end
-
-        if FileTest.exists?("/proc/vz/veinfo")
-            if FileTest.exists?("/proc/vz/version")
-                result = "openvzhn"
-            else
-                result = "openvzve"
+            if FileTest.exists?("/sys/bus/xen")
+                result = "xenu"
             end
-        end
-
-        if FileTest.exists?("/proc/self/status")
-            txt = File.read("/proc/self/status")
-            if txt =~ /^(s_context|VxID):[[:blank:]]*[1-9]/
-                result = "vserver"
-            end
-        end
-
-        if FileTest.exists?("/proc/virtual")
-            result = "vserver_host"
-        end
-
-        # new Xen domains have this in dom0 not domu :(
-        if FileTest.exists?("/proc/sys/xen/independent_wallclock")
-            result = "xenu" 
-        end
-        if FileTest.exists?("/sys/bus/xen")
-            result = "xenu" 
-        end
         
-        if FileTest.exists?("/proc/xen/capabilities")
-            txt = File.read("/proc/xen/capabilities")
-            if txt =~ /control_d/i
-                result = "xen0" 
+            if FileTest.exists?("/proc/xen/capabilities")
+                txt = File.read("/proc/xen/capabilities")
+                if txt =~ /control_d/i
+                    result = "xen0"
+                end
             end
         end
- 
+
         if result == "physical"
             output = Facter::Util::Resolution.exec('lspci')
             if not output.nil?
@@ -70,11 +57,10 @@ Facter.add("virtual") do
                     end
                 end
             end
-        end
-
-        # VMware server 1.0.3 rpm places vmware-vmx in this place, other versions or platforms may not.
-        if FileTest.exists?("/usr/lib/vmware/bin/vmware-vmx")
-            result = "vmware_server"
+            # VMware server 1.0.3 rpm places vmware-vmx in this place, other versions or platforms may not.
+            if FileTest.exists?("/usr/lib/vmware/bin/vmware-vmx")
+                result = "vmware_server"
+            end
         end
 
         result
@@ -86,7 +72,7 @@ Facter.add("is_virtual") do
 
     setcode do
         case Facter.value(:virtual)
-        when "xenu", "openvzve", "vmware" 
+        when "xenu", "openvzve", "vmware"
             true
         else 
             false
